##  Best Practices
Here are some best practices for configuring the dashboard:
  * [Start with Basic Filters](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio97d3b35fe55840129601970f533e50bd__section_vrz_wmm_5fc)
  * [Configure Advanced Filters](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio97d3b35fe55840129601970f533e50bd__section_d2m_xmm_5fc)
  * [Avoid Over-Scoping Filters](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio97d3b35fe55840129601970f533e50bd__section_vqg_ymm_5fc)
